import React, { FC, useEffect, useState } from 'react';
import { styles } from './styles';
import {
  Item,
  Label,
  NativeBase,
  RnViewStyleProp,
  Text,
  View,
} from 'native-base';
import { TouchableOpacity, Image } from 'react-native';
import { default as ImagePickerX } from 'react-native-image-picker';

// type imageDataProps = {
//   src: string;
//   dataBase64: string;
// };
export type ImageUploaderProps = {
  type?: 'avatar' | 'primary';
  ImagePickerStyle?: any;
  label?: string;
  style?: RnViewStyleProp;
  labelProps?: NativeBase.Label;
  validationInfo?: string[];
  onChange: (val: string) => void;
  value?: string;
};
const options = {
  title: 'Select Picture',
  storageOptions: {
    skipBackup: true,
    path: 'images',
  },
};
export const ImagePicker: FC<ImageUploaderProps> = (
  props: ImageUploaderProps
) => {
  const {
    type,
    label,
    labelProps,
    style,
    ImagePickerStyle,
    validationInfo,
    onChange,
    value,
  } = props;
  const [image, setImage] = useState<any>();
  const onPress = () => {
    ImagePickerX.showImagePicker(options, (response) => {
      if (response.didCancel) {
        console.log('User cancelled image picker');
      } else if (response.error) {
        console.log('ImagePicker Error: ', response.error);
      } else if (response.customButton) {
        console.log('User tapped custom button: ', response.customButton);
      } else {
        // const source = { uri: response.uri };
        setImage({ uri: response.uri });
        onChange(response.data);
      }
    });
  };
  useEffect(() => {
    if (value) {
      setImage({ uri: value });
    }
  }, []);
  const renderElement = (pickerStyleX?: any) => {
    return (
      <Item
        stackedLabel={label !== undefined}
        style={
          style !== undefined
            ? { ...styles.itemStyle, ...(style as object) }
            : styles.itemStyle
        }
      >
        {label && (
          <Label
            {...labelProps}
            style={
              labelProps?.style
                ? { ...styles.textDefault, ...(labelProps.style as object) }
                : styles.textDefault
            }
          >
            {label}
            {'   '}
            {validationInfo && validationInfo?.length > 0 && (
              <Text style={{ color: '#f39c12', marginLeft: 5 }}>
                {validationInfo}
              </Text>
            )}
          </Label>
        )}
        <TouchableOpacity onPress={onPress}>
          {!image ? (
            <View
              style={
                ImagePickerStyle
                  ? { ...ImagePickerStyle, ...pickerStyleX }
                  : pickerStyleX
              }
            >
              <Image
                style={{ height: 50, width: 50 }}
                source={require('./ImageIcon.png')}
              />
            </View>
          ) : (
            <Image
              source={image}
              style={
                ImagePickerStyle
                  ? { ...ImagePickerStyle, ...pickerStyleX }
                  : pickerStyleX
              }
            />
          )}
        </TouchableOpacity>
      </Item>
    );
  };
  if (type === 'avatar') {
    return renderElement(styles.avatar);
  }
  return renderElement(styles.defaultImage);
};
